@@ -237,6 +237,10 @@ class DriverAPI(RequestHandler):
     def fill_form(self, field_values):
         """
         Fill the fields identified by ``name`` with the content specified by ``value`` in a dict.
+        
+        Currently, fill_form supports the following fields: text, password, textarea, checkbox, radio and select.
+        
+        Checkboxes should be specified as a boolean in the dict.
         """
         raise NotImplementedError("%s doesn't support filling forms with a dict." % self.driver_name)
 
@@ -420,6 +424,12 @@ class DriverAPI(RequestHandler):
         """
         raise NotImplementedError("%s doesn't support verifying if element is not present by id" % self.driver_name)
 
+    def screenshot(self, name=None, suffix=None):
+        """
+        Takes a screenshot of the current page and saves it locally.
+        """
+        raise NotImplementedError("%s doesn't support taking screenshots." % self.driver_name)
+
     @property
     def cookies(self):
         """
